@@ -43,7 +43,7 @@
 #' # 4) return mapped colors
 #' xColormap(colormap="RdYlBu", data=runif(5))
 
-xColormap <- function(colormap=c("bwr","jet","gbr","wyr","br","yr","rainbow","wb","heat","terrain","topo","cm","ggplot2","jet.top","jet.bottom","jet.both","spectral","ggplot2.top","ggplot2.bottom","ggplot2.both","RdYlBu", "brewer.BrBG","brewer.PiYG","brewer.PRGn","brewer.PuOr","brewer.RdBu","brewer.RdGy","brewer.RdYlBu","brewer.RdYlGn","brewer.Spectral", "brewer.Blues","brewer.BuGn","brewer.BuPu","brewer.GnBu","brewer.Greens","brewer.Greys","brewer.Oranges","brewer.OrRd","brewer.PuBu","brewer.PuBuGn","brewer.PuRd","brewer.Purples","brewer.RdPu","brewer.Reds","brewer.YlGn","brewer.YlGnBu","brewer.YlOrBr","brewer.YlOrRd", "rainbow_hcl","heat_hcl","terrain_hcl","diverge_hcl", "hcl_br","hcl_bp","hcl_bb","hcl_gp","hcl_go","hcl_cp","hcl_cy","hcl_co", "sci_jco"), interpolate=c("spline","linear"), data=NULL, zlim=NULL)
+xColormap <- function(colormap=c("bwr","jet","gbr","wyr","br","yr","rainbow","wb","heat","terrain","topo","cm","ggplot2","jet.top","jet.bottom","jet.both","spectral","ggplot2.top","ggplot2.bottom","ggplot2.both","RdYlBu", "brewer.BrBG","brewer.PiYG","brewer.PRGn","brewer.PuOr","brewer.RdBu","brewer.RdGy","brewer.RdYlBu","brewer.RdYlGn","brewer.Spectral", "brewer.Blues","brewer.BuGn","brewer.BuPu","brewer.GnBu","brewer.Greens","brewer.Greys","brewer.Oranges","brewer.OrRd","brewer.PuBu","brewer.PuBuGn","brewer.PuRd","brewer.Purples","brewer.RdPu","brewer.Reds","brewer.YlGn","brewer.YlGnBu","brewer.YlOrBr","brewer.YlOrRd", "rainbow_hcl","heat_hcl","terrain_hcl","diverge_hcl", "hcl_br","hcl_bp","hcl_bb","hcl_gp","hcl_go","hcl_cp","hcl_cy","hcl_co", "sci_jco","sci_lancet","sci_nejm","sci_locuszoom"), interpolate=c("spline","linear"), data=NULL, zlim=NULL)
 {
 
 	interpolate <- match.arg(interpolate)
@@ -163,6 +163,18 @@ xColormap <- function(colormap=c("bwr","jet","gbr","wyr","br","yr","rainbow","wb
 			#https://cloud.r-project.org/web/packages/ggsci/vignettes/ggsci.html#jco
 			#via: noquote(paste0(ggsci::pal_jco("default",alpha=1)(3),collapse='","'))
 			palette.name <- colorRampPalette(c("#0073C2FF","#EFC000FF","#868686FF"), interpolate=interpolate)
+		}else if(colormap == "sci_nejm"){
+			#https://nanx.me/ggsci/reference/pal_nejm.html
+			#via: noquote(paste0(ggsci::pal_nejm("default",alpha=1)(8),collapse='","'))
+			palette.name <- colorRampPalette(c("#BC3C29FF","#0072B5FF","#E18727FF","#20854EFF","#7876B1FF","#6F99ADFF","#FFDC91FF","#EE4C97FF"), interpolate=interpolate)
+		}else if(colormap == "sci_lancet"){
+			#https://nanx.me/ggsci/reference/pal_lancet.html
+			#via: noquote(paste0(ggsci::pal_lancet("lanonc",alpha=1)(6),collapse='","'))
+			palette.name <- colorRampPalette(c("#00468BFF","#ED0000FF","#42B540FF","#0099B4FF","#925E9FFF","#FDAF91FF"), interpolate=interpolate)
+		}else if(colormap == "sci_locuszoom"){
+			#https://nanx.me/ggsci/reference/pal_locuszoom.html
+			#via: noquote(paste0(ggsci::pal_locuszoom("default",alpha=1)(6),collapse='","'))
+			palette.name <- colorRampPalette(c("#D43F3AFF","#EEA236FF","#5CB85CFF","#46B8DAFF","#357EBDFF","#9632B8FF"), interpolate=interpolate)
 		
 		}else if(colormap == "heat"){
 			palette.name <- grDevices::heat.colors
